@@ -8,9 +8,9 @@ use Log::ger;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-03'; # DATE
+our $DATE = '2023-02-10'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.008'; # VERSION
+our $VERSION = '1.009'; # VERSION
 
 our @EXPORT_OK = qw(
                        gen_csv_util
@@ -155,6 +155,8 @@ sub _instantiate_parser {
         $tcsv_opts{"quote_char"}  = undef;
         $tcsv_opts{"escape_char"} = undef;
     }
+    $tcsv_opts{always_quote} = 1 if $args->{"${prefix}always_quote"};
+    $tcsv_opts{quote_empty} = 1 if $args->{"${prefix}quote_empty"};
 
     Text::CSV_XS->new(\%tcsv_opts);
 }
@@ -433,6 +435,40 @@ This is like `--input-escape-char` option but for output instead of input.
 
 Defaults to `\\` (backslash). Overrides `--output-tsv` option.
 
+_
+        tags => ['category:output'],
+    },
+    output_always_quote => {
+        summary => 'Whether to always quote values',
+        schema => 'bool*',
+        default => 0,
+        description => <<'_',
+
+When set to false (the default), values are quoted only when necessary:
+
+    field1,field2,"field three contains comma (,)",field4
+
+When set to true, then all values will be quoted:
+
+    "field1","field2","field three contains comma (,)","field4"
+
+_
+        tags => ['category:output'],
+    },
+    output_quote_empty => {
+        summary => 'Whether to quote empty values',
+        schema => 'bool*',
+        default => 0,
+        description => <<'_',
+
+When set to false (the default), empty values are not quoted:
+
+    field1,field2,,field4
+
+When set to true, then empty values will be quoted:
+
+    field1,field2,"",field4
+
 _
         tags => ['category:output'],
     },
@@ -1710,7 +1746,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 1.008 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2023-02-03.
+This document describes version 1.009 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2023-02-10.
 
 =head1 DESCRIPTION
 
