@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-03'; # DATE
+our $DATE = '2023-02-10'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.008'; # VERSION
+our $VERSION = '1.009'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -121,7 +121,7 @@ App::CSVUtils::csv_sort_fields - Sort CSV fields
 
 =head1 VERSION
 
-This document describes version 1.008 of App::CSVUtils::csv_sort_fields (from Perl distribution App-CSVUtils), released on 2023-02-03.
+This document describes version 1.009 of App::CSVUtils::csv_sort_fields (from Perl distribution App-CSVUtils), released on 2023-02-10.
 
 =for Pod::Coverage ^(on|after|before)_.+$
 
@@ -226,6 +226,18 @@ Overriden by C<--input-sep-char>, C<--input-quote-char>, C<--input-escape-char>
 options. If one of those options is specified, then C<--input-tsv> will be
 ignored.
 
+=item * B<output_always_quote> => I<bool> (default: 0)
+
+Whether to always quote values.
+
+When set to false (the default), values are quoted only when necessary:
+
+ field1,field2,"field three contains comma (,)",field4
+
+When set to true, then all values will be quoted:
+
+ "field1","field2","field three contains comma (,)","field4"
+
 =item * B<output_escape_char> => I<str>
 
 Specify character to escape value in field in output CSV, will be passed to Text::CSV_XS.
@@ -261,6 +273,18 @@ This is like C<--input-quote-char> option but for output instead of input.
 
 Defaults to C<"> (double quote). Overrides C<--output-tsv> option.
 
+=item * B<output_quote_empty> => I<bool> (default: 0)
+
+Whether to quote empty values.
+
+When set to false (the default), empty values are not quoted:
+
+ field1,field2,,field4
+
+When set to true, then empty values will be quoted:
+
+ field1,field2,"",field4
+
 =item * B<output_sep_char> => I<str>
 
 Specify field separator character in output CSV, will be passed to Text::CSV_XS.
